[−][src]Struct extrahop::activitymap::query::Query
Envelope for an ad-hoc activity map query.
Construction
If constructed with struct literal syntax, Query::default() must
be used to ensure source compatibility with future library updates.
Fields
from: QueryTimeThe absolute or relative timestamp at which the query should start.
until: QueryTimeThe absolute or relative timestmap at which the query should end. If not set, defaults to the current packet time of the appliance.
walks: Vec<Walk>The traversals that should be performed across the topology. Results from all walks will be merged into a single set of edges in the response.
weighting: WeightingThe set of metrics should drive the weight of an edge.
edge_annotations: Vec<EdgeAnnotation>The additional data to return for each edge.