[−][src]Struct extrahop::activitymap::query::Walk
A set of steps from one or more starting points which build a directed graph topology.
Fields
origins: WalkOriginThe starting device(s) for the walk.
steps: Vec<Step>The ordered set of steps to take away from the walk origins.